--- vlc/modules/control/rc.c.rcsay~	2004-07-26 10:05:29.000000000 +0800
+++ vlc/modules/control/rc.c	2004-08-08 12:23:34.000000000 +0800
@@ -36,6 +36,7 @@
 #include <vlc/intf.h>
 #include <vlc/aout.h>
 #include <vlc/vout.h>
+#include <osd.h>
 
 #ifdef HAVE_UNISTD_H
 #    include <unistd.h>
@@ -85,12 +86,18 @@
                            vlc_value_t, vlc_value_t, void * );
 static int  AudioConfig  ( vlc_object_t *, char const *,
                            vlc_value_t, vlc_value_t, void * );
+static int  Say          ( vlc_object_t *, char const *,
+                           vlc_value_t, vlc_value_t, void * );
+static int  ShutUp       ( vlc_object_t *, char const *,
+                           vlc_value_t, vlc_value_t, void * );
 
 struct intf_sys_t
 {
     int i_socket_listen;
     int i_socket;
     char *psz_unix_path;
+    vout_thread_t *p_vout;
+    int i_channel;
 
 #ifdef WIN32
     HANDLE hConsoleIn;
@@ -290,6 +297,8 @@
     p_input = NULL;
     p_playlist = NULL;
 
+    p_intf->p_sys->p_vout = NULL;
+
     /* Register commands that will be cleaned up upon object destruction */
     var_Create( p_intf, "quit", VLC_VAR_VOID | VLC_VAR_ISCOMMAND );
     var_AddCallback( p_intf, "quit", Quit, NULL );
@@ -336,6 +345,10 @@
     var_AddCallback( p_intf, "adev", AudioConfig, NULL );
     var_Create( p_intf, "achan", VLC_VAR_STRING | VLC_VAR_ISCOMMAND );
     var_AddCallback( p_intf, "achan", AudioConfig, NULL );
+    var_Create( p_intf, "say", VLC_VAR_STRING | VLC_VAR_ISCOMMAND );
+    var_AddCallback( p_intf, "say", Say, NULL );
+    var_Create( p_intf, "shutup", VLC_VAR_STRING | VLC_VAR_ISCOMMAND );
+    var_AddCallback( p_intf, "shutup", ShutUp, NULL );
 
 #ifdef WIN32
     /* Get the file descriptor of the console input */
@@ -361,6 +374,11 @@
 
         b_complete = ReadCommand( p_intf, p_buffer, &i_size );
 
+        if(p_intf->p_sys->p_vout && p_intf->p_sys->p_vout->b_die) {
+	    vlc_object_release(p_intf->p_sys->p_vout);
+	    p_intf->p_sys->p_vout = NULL;
+        }
+
         /* Manage the input part */
         if( p_input == NULL )
         {
@@ -908,6 +926,29 @@
     return i_error;
 }
 
+static int Say( vlc_object_t *p_this, char const *psz_cmd,
+                vlc_value_t oldval, vlc_value_t newval, void *p_data )
+{
+    intf_thread_t *p_intf = (intf_thread_t*)p_this;
+    p_intf->p_sys->p_vout=vlc_object_find( p_intf, VLC_OBJECT_VOUT, FIND_ANYWHERE );
+    if(!p_intf->p_sys->p_vout) {
+	    msg_Warn(p_intf, "No VLC_OBJECT_VOUT found");
+	    return 1;
+    }
+    
+    msg_Dbg(p_intf, "Say() doing something");
+    return vout_ShowTextRelative(p_intf->p_sys->p_vout, DEFAULT_CHAN, psz_cmd + 4, NULL, OSD_ALIGN_TOP|OSD_ALIGN_LEFT, 10, 10, 10000000);
+}
+
+static int ShutUp( vlc_object_t *p_this, char const *psz_cmd,
+                   vlc_value_t oldval, vlc_value_t newval, void *p_data )
+{
+    intf_thread_t *p_intf = (intf_thread_t*)p_this;
+    if(p_intf->p_sys->p_vout)
+	vout_ClearOSDChannel(p_intf, DEFAULT_CHAN);
+    return 0;
+}
+
 #ifdef WIN32
 vlc_bool_t ReadWin32( intf_thread_t *p_intf, char *p_buffer, int *pi_size )
 {
